#!/usr/bin/env bash
set -euo pipefail

echo "-- Loading JOB tables..."
echo <<EOF
COPY aka_name        FROM '../tmp/job/aka_name.csv'        CSV ESCAPE '\';
COPY aka_title       FROM '../tmp/job/aka_title.csv'       CSV ESCAPE '\';
COPY cast_info       FROM '../tmp/job/cast_info.csv'       CSV ESCAPE '\';
COPY char_name       FROM '../tmp/job/char_name.csv'       CSV ESCAPE '\';
COPY company_name    FROM '../tmp/job/company_name.csv'    CSV ESCAPE '\';
COPY company_type    FROM '../tmp/job/company_type.csv'    CSV ESCAPE '\';
COPY comp_cast_type  FROM '../tmp/job/comp_cast_type.csv'  CSV ESCAPE '\';
COPY complete_cast   FROM '../tmp/job/complete_cast.csv'   CSV ESCAPE '\';
COPY info_type       FROM '../tmp/job/info_type.csv'       CSV ESCAPE '\';
COPY keyword         FROM '../tmp/job/keyword.csv'         CSV ESCAPE '\';
COPY kind_type       FROM '../tmp/job/kind_type.csv'       CSV ESCAPE '\';
COPY link_type       FROM '../tmp/job/link_type.csv'       CSV ESCAPE '\';
COPY movie_companies FROM '../tmp/job/movie_companies.csv' CSV ESCAPE '\';
COPY movie_info      FROM '../tmp/job/movie_info.csv'      CSV ESCAPE '\';
COPY movie_info_idx  FROM '../tmp/job/movie_info_idx.csv'  CSV ESCAPE '\';
COPY movie_keyword   FROM '../tmp/job/movie_keyword.csv'   CSV ESCAPE '\';
COPY movie_link      FROM '../tmp/job/movie_link.csv'      CSV ESCAPE '\';
COPY name            FROM '../tmp/job/name.csv'            CSV ESCAPE '\';
COPY person_info     FROM '../tmp/job/person_info.csv'     CSV ESCAPE '\';
COPY role_type       FROM '../tmp/job/role_type.csv'       CSV ESCAPE '\';
COPY title           FROM '../tmp/job/title.csv'           CSV ESCAPE '\';
EOF

echo "-- Transforming JOB movie ratings"
cat loadMovieInfo.sql

echo "-- Generating Queries"
# JOB extended Q34 [0, 10000000] in 100000 increments
for THRESHOLD in $(seq 0 100000 10000000); do
  QUERY=$(sed '/^--/d' 34.sql | sed "s/\\\$THRESHOLD.*/$THRESHOLD/")
  echo $QUERY
done

# JOB extended Q35 [0, 5000000] in 166666 increments
for THRESHOLD in $(seq 0 166666 5000000); do
  QUERY=$(sed '/^--/d' 35.sql | sed "s/\\\$THRESHOLD.*/$THRESHOLD/")
  echo $QUERY
done

# JOB extended Q36 [1, 9.5] in .5 increments
for THRESHOLD in $(LANG=en_us seq 1 .5 9.5); do
  QUERY=$(sed '/^--/d' 36.sql | sed "s/\\\$THRESHOLD.*/$THRESHOLD/")
  echo $QUERY
done

# JOB extended Q37 [1.5, 9.5] in .5 increments
for THRESHOLD in $(LANG=en_us seq 1.5 .5 9.5); do
  QUERY=$(sed '/^--/d' 37.sql | sed "s/\\\$THRESHOLD.*/$THRESHOLD/")
  echo $QUERY
done

# JOB extended Q38 [1.5, 9] in .5 increments
for THRESHOLD in $(LANG=en_us seq 1.5 .5 9); do
  QUERY=$(sed '/^--/d' 38.sql | sed "s/\\\$THRESHOLD.*/$THRESHOLD/")
  echo $QUERY
done
