#!/usr/bin/env bash
set -euo pipefail

# Clone repo first to see what datasets are available
if [ ! -d public_bi_benchmark ]; then
  git clone --depth=1 https://github.com/cwida/public_bi_benchmark public_bi_benchmark
else
  (
    cd public_bi_benchmark
    git checkout -- .
    git pull >/dev/null
  )
fi

usage() {
  cat <<EOM
Usage: $(basename "$0") <dataset>
  dataset    the dataset which should be used to generate a database
             possible choices:
$(find public_bi_benchmark/benchmark -mindepth 1 -maxdepth 1 -type d -exec basename {} \; | sort | xargs -L1 printf "             %s\n")
EOM
}

if [ "$#" -ne 1 ]; then
  usage
  exit 1
fi

(
  cd "public_bi_benchmark/benchmark/$1"
  # fix non-standard double types in tables
  find . -name '*.sql' -print0 | xargs -0 -L1 -P "$(nproc)" sed -i 's/double/real/'
  # download data-urls
  xargs <data-urls.txt -L1 curl -sOLC -
  # extract bz2 files
  find . -name '*.csv.bz2' -print0 | xargs -0 -L1 -P "$(nproc)" -i sh -c 'bunzip2 -k {} 2>/dev/null || true'
)

# create and load data
echo "-- Creating database db/pubBI/$1.db"
TABLES=$(find "public_bi_benchmark/benchmark/$1/tables/" -name '*.table.sql' -exec basename {} \; | cut -f 1 -d .)
SCHEMAFILES=$(echo "$TABLES" | xargs printf "public_bi_benchmark/benchmark/$1/tables/%s.table.sql\n")
LOADSCRIPT=$(echo "$TABLES" | xargs -I@ printf "COPY \"%s\" FROM 'public_bi_benchmark/benchmark/$1/%s.csv' DELIMITER '|' NULL 'null';\n" @ @)
# shellcheck disable=SC2086
echo $SCHEMAFILES
echo $LOADSCRIPT
