#!/bin/env Rscript
library(data.table)
library(fabricatr)
library(sads)

args = commandArgs(trailingOnly=TRUE)
if (length(args) < 1) {
  stop("Usage: ./dbgen.r /path/to/tpch_data", call.=FALSE)
}
setwd(args[1])

# Load existing lineitem table and generate different price & quantity columns
lineitem <- fread('lineitem.tbl', sep = '|', col.names = c('l_orderkey', 'l_partkey', 'l_suppkey', 'l_linenumber', 'l_quantity', 'l_extendedprice', 'l_discount', 'l_tax', 'l_returnflag', 'l_linestatus', 'l_shipdate', 'l_commitdate', 'l_receiptdate', 'l_shipinstruct', 'l_shipmode', 'l_comment'))
# Generate anti-correlated quantity
lineitem[, correlated_quantity := pmax(1, correlate(given = lineitem$l_extendedprice, rho = -.7, draw_count, mean = mean(lineitem$l_quantity)))]
# Generate Zipf-skewed quantity
lineitem[, zipf_quantity := rzipf(nrow(lineitem), N = max(lineitem$l_quantity), s =.5)]
# Schema: lineitem += (correlated_quantity, zipf_quantity)
fwrite(lineitem, "custom_lineitem.tbl", sep = '|', col.names = FALSE)
